QuicUIApp class
Complete app integration example
Constructors
Properties
- backend ↔ QuicUIFirebase
-
getter/setter pair
- currentScreenId ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void - Cleanup
-
init(
) → Future< void> - Initialize app
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setupRealtime(
) → void - Setup real-time updates
-
showScreen(
String screenId) → Future< void> - Load and render screen
-
submitForm(
String formId, Map< String, dynamic> data) → Future<void> - Submit form from current screen
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited